==> openshift-model-monitoring-5.10.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/AlertmanagerEndpointsFluent.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.model.IntOrString;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.IntOrStringFluent;
import io.fabric8.kubernetes.api.model.IntOrStringBuilder;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface AlertmanagerEndpointsFluent<A extends io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getApiVersion();
  public A withApiVersion(java.lang.String apiVersion);
  public java.lang.Boolean hasApiVersion();
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0);
  public java.lang.String getBearerTokenFile();
  public A withBearerTokenFile(java.lang.String bearerTokenFile);
  public java.lang.Boolean hasBearerTokenFile();
  
  /**
   * Method is deprecated. use withBearerTokenFile instead.
   */
  @java.lang.Deprecated
  public A withNewBearerTokenFile(java.lang.String arg0);
  public java.lang.String getName();
  public A withName(java.lang.String name);
  public java.lang.Boolean hasName();
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0);
  public java.lang.String getNamespace();
  public A withNamespace(java.lang.String namespace);
  public java.lang.Boolean hasNamespace();
  
  /**
   * Method is deprecated. use withNamespace instead.
   */
  @java.lang.Deprecated
  public A withNewNamespace(java.lang.String arg0);
  public java.lang.String getPathPrefix();
  public A withPathPrefix(java.lang.String pathPrefix);
  public java.lang.Boolean hasPathPrefix();
  
  /**
   * Method is deprecated. use withPathPrefix instead.
   */
  @java.lang.Deprecated
  public A withNewPathPrefix(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildPort instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.IntOrString getPort();
  public io.fabric8.kubernetes.api.model.IntOrString buildPort();
  public A withPort(io.fabric8.kubernetes.api.model.IntOrString port);
  public java.lang.Boolean hasPort();
  public A withNewPort(java.lang.Integer intVal);
  public A withNewPort(java.lang.String strVal);
  public io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent.PortNested<A> withNewPort();
  public io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent.PortNested<A> withNewPortLike(io.fabric8.kubernetes.api.model.IntOrString item);
  public io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent.PortNested<A> editPort();
  public io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent.PortNested<A> editOrNewPort();
  public io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent.PortNested<A> editOrNewPortLike(io.fabric8.kubernetes.api.model.IntOrString item);
  public java.lang.String getScheme();
  public A withScheme(java.lang.String scheme);
  public java.lang.Boolean hasScheme();
  
  /**
   * Method is deprecated. use withScheme instead.
   */
  @java.lang.Deprecated
  public A withNewScheme(java.lang.String arg0);
  public java.lang.String getTimeout();
  public A withTimeout(java.lang.String timeout);
  public java.lang.Boolean hasTimeout();
  
  /**
   * Method is deprecated. use withTimeout instead.
   */
  @java.lang.Deprecated
  public A withNewTimeout(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildTlsConfig instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.monitoring.v1.TLSConfig getTlsConfig();
  public io.fabric8.openshift.api.model.monitoring.v1.TLSConfig buildTlsConfig();
  public A withTlsConfig(io.fabric8.openshift.api.model.monitoring.v1.TLSConfig tlsConfig);
  public java.lang.Boolean hasTlsConfig();
  public io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent.TlsConfigNested<A> withNewTlsConfig();
  public io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent.TlsConfigNested<A> withNewTlsConfigLike(io.fabric8.openshift.api.model.monitoring.v1.TLSConfig item);
  public io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent.TlsConfigNested<A> editTlsConfig();
  public io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent.TlsConfigNested<A> editOrNewTlsConfig();
  public io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent.TlsConfigNested<A> editOrNewTlsConfigLike(io.fabric8.openshift.api.model.monitoring.v1.TLSConfig item);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface PortNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.IntOrStringFluent<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent.PortNested<N>>{
    public N and();
    public N endPort();
    
  }
  public interface TlsConfigNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.monitoring.v1.TLSConfigFluent<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent.TlsConfigNested<N>>{
    public N and();
    public N endTlsConfig();
    
  }
  
}

==> openshift-model-monitoring-5.12.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/AlertmanagerEndpointsFluent.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.model.IntOrString;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.IntOrStringBuilder;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.IntOrStringFluent;
import java.lang.Integer;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface AlertmanagerEndpointsFluent<A extends io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getApiVersion();
  public A withApiVersion(java.lang.String apiVersion);
  public java.lang.Boolean hasApiVersion();
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildAuthorization instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.monitoring.v1.SafeAuthorization getAuthorization();
  public io.fabric8.openshift.api.model.monitoring.v1.SafeAuthorization buildAuthorization();
  public A withAuthorization(io.fabric8.openshift.api.model.monitoring.v1.SafeAuthorization authorization);
  public java.lang.Boolean hasAuthorization();
  public io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent.AuthorizationNested<A> withNewAuthorization();
  public io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent.AuthorizationNested<A> withNewAuthorizationLike(io.fabric8.openshift.api.model.monitoring.v1.SafeAuthorization item);
  public io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent.AuthorizationNested<A> editAuthorization();
  public io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent.AuthorizationNested<A> editOrNewAuthorization();
  public io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent.AuthorizationNested<A> editOrNewAuthorizationLike(io.fabric8.openshift.api.model.monitoring.v1.SafeAuthorization item);
  public java.lang.String getBearerTokenFile();
  public A withBearerTokenFile(java.lang.String bearerTokenFile);
  public java.lang.Boolean hasBearerTokenFile();
  
  /**
   * Method is deprecated. use withBearerTokenFile instead.
   */
  @java.lang.Deprecated
  public A withNewBearerTokenFile(java.lang.String arg0);
  public java.lang.String getName();
  public A withName(java.lang.String name);
  public java.lang.Boolean hasName();
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0);
  public java.lang.String getNamespace();
  public A withNamespace(java.lang.String namespace);
  public java.lang.Boolean hasNamespace();
  
  /**
   * Method is deprecated. use withNamespace instead.
   */
  @java.lang.Deprecated
  public A withNewNamespace(java.lang.String arg0);
  public java.lang.String getPathPrefix();
  public A withPathPrefix(java.lang.String pathPrefix);
  public java.lang.Boolean hasPathPrefix();
  
  /**
   * Method is deprecated. use withPathPrefix instead.
   */
  @java.lang.Deprecated
  public A withNewPathPrefix(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildPort instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.IntOrString getPort();
  public io.fabric8.kubernetes.api.model.IntOrString buildPort();
  public A withPort(io.fabric8.kubernetes.api.model.IntOrString port);
  public java.lang.Boolean hasPort();
  public A withNewPort(java.lang.Integer intVal);
  public A withNewPort(java.lang.String strVal);
  public io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent.PortNested<A> withNewPort();
  public io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent.PortNested<A> withNewPortLike(io.fabric8.kubernetes.api.model.IntOrString item);
  public io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent.PortNested<A> editPort();
  public io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent.PortNested<A> editOrNewPort();
  public io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent.PortNested<A> editOrNewPortLike(io.fabric8.kubernetes.api.model.IntOrString item);
  public java.lang.String getScheme();
  public A withScheme(java.lang.String scheme);
  public java.lang.Boolean hasScheme();
  
  /**
   * Method is deprecated. use withScheme instead.
   */
  @java.lang.Deprecated
  public A withNewScheme(java.lang.String arg0);
  public java.lang.String getTimeout();
  public A withTimeout(java.lang.String timeout);
  public java.lang.Boolean hasTimeout();
  
  /**
   * Method is deprecated. use withTimeout instead.
   */
  @java.lang.Deprecated
  public A withNewTimeout(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildTlsConfig instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.monitoring.v1.TLSConfig getTlsConfig();
  public io.fabric8.openshift.api.model.monitoring.v1.TLSConfig buildTlsConfig();
  public A withTlsConfig(io.fabric8.openshift.api.model.monitoring.v1.TLSConfig tlsConfig);
  public java.lang.Boolean hasTlsConfig();
  public io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent.TlsConfigNested<A> withNewTlsConfig();
  public io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent.TlsConfigNested<A> withNewTlsConfigLike(io.fabric8.openshift.api.model.monitoring.v1.TLSConfig item);
  public io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent.TlsConfigNested<A> editTlsConfig();
  public io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent.TlsConfigNested<A> editOrNewTlsConfig();
  public io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent.TlsConfigNested<A> editOrNewTlsConfigLike(io.fabric8.openshift.api.model.monitoring.v1.TLSConfig item);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface AuthorizationNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.monitoring.v1.SafeAuthorizationFluent<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent.AuthorizationNested<N>>{
    public N and();
    public N endAuthorization();
    
  }
  public interface PortNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.IntOrStringFluent<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent.PortNested<N>>{
    public N and();
    public N endPort();
    
  }
  public interface TlsConfigNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.monitoring.v1.TLSConfigFluent<io.fabric8.openshift.api.model.monitoring.v1.AlertmanagerEndpointsFluent.TlsConfigNested<N>>{
    public N and();
    public N endTlsConfig();
    
  }
  
}
